/*
 * Copyright (c) 2012-2014 Wind River Systems, Inc.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

#include <stdio.h>
#include <dfu/dfu_target_mcuboot.h>

#include <zephyr/logging/log.h>
#define LOG_MODULE_NAME main
LOG_MODULE_REGISTER(LOG_MODULE_NAME);

#define CHUNK_SIZE    156
#define FW_SIZE CHUNK_SIZE * 0x400

__ALIGN(4) static uint8_t fw_image[CHUNK_SIZE];


int main(void)
{
	int err;
	size_t offset = 0;
	__ALIGN(4) uint8_t dfu_buf[(CHUNK_SIZE + 3) & ~3];

	memset(fw_image, 0xAA, sizeof(fw_image));
	
	err = dfu_target_mcuboot_set_buf(dfu_buf, sizeof(dfu_buf));
	LOG_INF("dfu_target_mcuboot_set_buf: %d. Size: %d ", err, sizeof(dfu_buf));
	
	err = dfu_target_init(DFU_TARGET_IMAGE_TYPE_MCUBOOT, 0, FW_SIZE, NULL);
	LOG_INF("dfu_target_init:%d", err);

	do {
		err = dfu_target_write(fw_image, CHUNK_SIZE);
		if (err) {
			LOG_ERR("dfu_target_write() failed. (err %d)", err);
			return 0;
		}
		offset += CHUNK_SIZE;

	} while (offset <= FW_SIZE);

	LOG_INF("Hello World! %s", CONFIG_BOARD);
	return 0;
}
